name="Scrambler"
author="mDuo13"
help="""This is a game to play when things get really boring in the server lobby. \n\n\
Anyone in the lobby who answers can receive points. The first one to figure out what \
the scrambled word is gets 2 points, or 1 if you had to give them a hint.\n\n\
Type '/scramble category *category*' to set a new category.\n\n\
Type '/scramble new *word*' to scramble the word or phrase *word* and start to play.\n\n\
Type '/scramble reset' to reset all the scores.\n\n\
Type '/scramble end' to cancel a current word scramble.\n\n\
Type '/scramble hint *hint*' to give the hint *hint* to the players, making the word scramble only worth 1 point.\n\n\
Have fun, and don't forget to visit my site at http://mduo13.no-ip.org/"""
#'name' should contain your plugin's long name.
#       Make sure it's not the same as another plugin's name.
#'author' is the author of the plugin. It will be listed in the plugin info.
#'help' is the help text that will be displayed when the user clicks the
#       'Plugin Info' button.
#--------------------------------------
import os
from random import randint
from string import find, replace
chat=None
session=None
tree=None
openrpg=None

hint = 0
scores = {}
scambled_word = ""
unscrambled_word = ""
success_msgs =  ["Bingo! %name gets it. %name's score goes up by %points to %score! The answer was: %word",
                 "Congratulations, %name! You correctly guessed %word, bringing your score up +%points to %score!",
                 "The point goes to %name for %word. %name's gets %points point, for a total of %score",
                 "And %name has it, with %word. %name's score goes up %points point to %score.",
                 "Good job, %name. %word is the correct answer. Score +%points, up to %score."]
category = ""
challenge_on = 0

def scramble(txt):
    split_txt = txt.split()
    mastertxt = ""
    for word in split_txt:
        nuword = word
        while nuword == word and len(word)>1:
            for x in range(0,len(txt)+5):
                n = randint(1,len(txt))
                nuword = nuword[1:n]+nuword[0]+nuword[n:]
        mastertxt+=nuword+" "
    return mastertxt

##Now we have the functions. These are called from within OpenRPG at various
##times. You can reference and change the variables, and do other things too.
##The more you know about python and OpenRPG, the more you can do. The
##possibilities are larger than you'd think.
##Note that when I say "formatted" I mean that it has HTML tags like font colors
##and names already added.

def message(self, text):
    #This is called whenever the user types something and hits enter.
    #It covers all messages, before they are formatted.
    return text

def send_msg(self, text, send):
    #This is called when a message is about to be sent out.
    #It covers all messages sent by the user, before they have been formatted.
    #If send is set to 0, the message will not be sent out to other
    #users, but it will still be posted to the user's chat normally.
    #Otherwise, send defaults to 1. (The message is sent as normal)
    return text, send

def receive_msg(self, text, type, name, player):
    #This is called whenever a message from someone else is received, no matter
    #what type of message it is.
    #The text variable is the text of the message. If the type is a regular
    #message, it is already formatted. Otherwise, it's not.
    #The type variable is an integer which tells you the type: 1=chat, 2=whisper
    #3=emote, 4=info, and 5=system.
    #The name variable is the name of the player who sent you the message.
    #The player variable contains lots of info about the player sending the
    #message, including name, ID#, and currently-set role.
    #Uncomment the following line to see the format for the player variable.
    #print player
    posted = 0#If posted is set to 1 then the chat module will stop processing
    #the incoming message. Use this if you post the incoming message elsewhere,
    #for example in a special tab or window.
    global scrambled_word, unscrambled_word, scores, challenge_on, hint
    if text.lower().find(unscrambled_word) > -1 and challenge_on:
        challenge_on = 0
        if hint == 1:
            points = 1
        else:
            points = 2
        if name in scores.keys():
            scores[name] += points
        else:
            scores[name] = points
        n = randint(0,len(success_msgs)-1)
        da_msg = success_msgs[n].replace("%name", name).replace("%score", str(scores[name])).replace("%word",unscrambled_word).replace("%points", str(points))
        chat.Post(da_msg, 1, 1)
    return text, type, name, posted

def post_msg(self, text, myself):
    #This is called whenever a message written by the user is about to be posted
    #to chat; it doesn't affect the copy of the message that gets sent to others
    return text

def docmd(self, text, cmdlist):
    #This is called when the user enters a / command that OpenRPG doesn't
    #recognize. Thus, you can create new / commands. The text variable
    #is the text that the user inputted. If it is your custom command,
    #return 1. If it is not, return 0.
    global scrambled_word, unscrambled_word, scores, category, challenge_on, hint
    if text.lower()[:9]!="/scramble":
        return 0
    elif text[10:13].lower() == "new":
        unscrambled_word = text[14:].lower()
        scrambled_word = scramble(text[14:])
        if unscrambled_word[-1] == " ":
            unscrambled_word = unscrambled_word[:-1]
        if scrambled_word[-1] == " ":
            scrambled_word = scrambled_word[:-1]
        chat.Post("Here we go! The category is <b>"+category+"</b> and the word/phrase is <b>"+scrambled_word+"</b>! First one to shout out the answer gets the point(s)!", 1, 1)
        challenge_on = 1
        hint = 0
    elif text[10:15].lower() == "reset":
        scores={}
        chat.Post("All SCRAMBLE scores have been reset.", 1, 1)
    elif text[10:18].lower() == "category":
        category = text[19:]
        chat.Post("New SCRAMBLE category: <b>"+text[19:]+"</b>.", 1, 1)
    elif text[10:13].lower() == "end":
        if challenge_on == 0:
            chat.Post("You can't end a challenge that doesn't exist!")
        else:
            chat.Post("SCRAMBLE challenge cancelled. The correct answer was '"+unscrambled_word+"'.", 1, 1)
            challenge_on = 0
    elif text[10:14].lower() == "hint":
        chat.Post("<b>Hint:</b> "+text[15:], 1, 1)
        hint = 1
    elif text[10:16].lower() == "scores":
        scorelist = "The current scores are:"
        for name in scores.keys():
            scorelist += "<br>"+name+" : "+str(scores[name])
        chat.Post(scorelist, 1, 1)
    else:
        chat.Post("Bad syntax for SCRAMBLE. Check the plugin info for the correct usage.")
    return 1

def refresh_counter(self):
    #This is called once per second. That's all you need to know.
    pass

def close_module(self):
    #This is called when OpenRPG shuts down
    pass
